package io.renren.modules.app.dao;

import io.renren.modules.app.entity.XlkEntity;
import io.renren.modules.app.entity.YwpzDyEntity;
import io.renren.modules.app.entity.YwpzEntity;
import com.baomidou.mybatisplus.mapper.BaseMapper;

import java.util.List;
import java.util.Map;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * 个人缴款通知书
 *
 * @author ly
 * @email 1271428398@qq.com
 * @date 2019-03-22 09:53:01
 */
@Mapper
public interface XlkDao extends BaseMapper<XlkEntity> {

	// 下拉框
	List<XlkEntity> selectxlkxq(@Param(value = "_pt") String _pt);

	List<XlkEntity> selectxm(String bm);

	List<XlkEntity> selectlz(String bm);

	List<XlkEntity> selectkmlb();

	List<XlkEntity> selectkmlbbyid(String id);

	List<XlkEntity> selectkjqj();

	List<XlkEntity> selectkm();

	List<XlkEntity> selectpzh();

	XlkEntity selectkmmc(String id);

	// 项目下拉框
	List<XlkEntity> selectXMxlk(@Param(value = "_pt") String _pt);

	// 项目下拉框根据小区编码查询
	List<XlkEntity> selectXMxlk2(@Param(value = "_pt") String _pt);

	// 幢号下拉框
	List<XlkEntity> selectZHxlk(String xmbm);

	// 门牌号下拉框
	List<XlkEntity> selectMPHxlk(String dhbm);

	List<XlkEntity> selectfwxz(String id);

	// 门牌号下拉框
	List<XlkEntity> selectMPHxlk2(String mh);

	// 单元下拉框
	List<XlkEntity> selectDYxlk(String dhbm);

	// 开发单位下拉框
	List<XlkEntity> selectKFDWxlk(@Param(value = "_pt") String _pt);

	// 物业公司下拉框
	List<XlkEntity> selectwygs();

	// 管委会下拉框
	List<XlkEntity> selectgwhxx();

	List<XlkEntity> selectdwjjl(Map<String, String> map);

	List<XlkEntity> selectczyy();

	List<XlkEntity> selectcwkjqj();

	List<XlkEntity> selectjzszkm();
	
	List<XlkEntity> selectjxmall(@Param(value = "_pt") String _pt);
	
	List<XlkEntity> selectDWBYXM(String id);
	
	List<XlkEntity> selectDYBMBYXM(String id);
	
	List<XlkEntity> selectDYBMBYSQDBH(String id);
	
	List<XlkEntity> selectYELDXLK(String id);
	
	List<XlkEntity> selectYEDYXLK(String id);
}
